<?php
/**
 * Registering meta boxes
 *
 * In this file, I'll show you how to extend the class to add more field type (in this case, the 'taxonomy' type)
 * All the definitions of meta boxes are listed below with comments, please read them carefully.
 * Note that each validation method of the Validation Class MUST return value instead of boolean as before
 *
 * You also should read the changelog to know what has been changed
 *
 * For more information, please visit: http://www.deluxeblogtips.com/2010/04/how-to-create-meta-box-wordpress-post.html
 *
 */

/********************* BEGIN EXTENDING CLASS ***********************/

/**
 * Extend RW_Meta_Box class
 * Add field type: 'taxonomy'
 */
class RW_Meta_Box_Taxonomy extends RW_Meta_Box {
	
	function add_missed_values() {
		parent::add_missed_values();
		
		// add 'multiple' option to taxonomy field with checkbox_list type
		foreach ($this->_meta_box['fields'] as $key => $field) {
			if ('taxonomy' == $field['type'] && 'checkbox_list' == $field['options']['type']) {
				$this->_meta_box['fields'][$key]['multiple'] = true;
			}
		}
	}
	
	// show taxonomy list
	function show_field_taxonomy($field, $meta) {
		global $post;
		
		if (!is_array($meta)) $meta = (array) $meta;
		
		$this->show_field_begin($field, $meta);
		
		$options = $field['options'];
		$terms = get_terms($options['taxonomy'], $options['args']);
		
		// checkbox_list
		if ('checkbox_list' == $options['type']) {
			foreach ($terms as $term) {
				echo "<input type='checkbox' name='{$field['id']}[]' value='$term->slug'" . checked(in_array($term->slug, $meta), true, false) . " /> $term->name<br/>";
			}
		}
		// select
		else {
			echo "<select name='{$field['id']}" . ($field['multiple'] ? "[]' multiple='multiple' style='height:auto'" : "'") . ">";
		
			foreach ($terms as $term) {
				echo "<option value='$term->slug'" . selected(in_array($term->slug, $meta), true, false) . ">$term->name</option>";
			}
			echo "</select>";
		}
		
		$this->show_field_end($field, $meta);
	}
}

/********************* END EXTENDING CLASS ***********************/

/********************* BEGIN DEFINITION OF META BOXES ***********************/

// prefix of meta keys, optional
// use underscore (_) at the beginning to make keys hidden, for example $prefix = '_rw_';
// you also can make prefix empty to disable it

$of_categories2 = array();  
		$of_categories_obj2 = get_categories('hide_empty=0');
		foreach ($of_categories_obj2 as $of_cat2) {
		    $of_categories2[$of_cat2->cat_ID] = $of_cat2->cat_name . " : " . $of_cat2->cat_ID;
		}

$prefix = 'metaibt_';

$meta_boxes = array();

// meta box
$meta_boxes[] = array(
	'id' => 'post_options',
	'title' => 'Post Options',
	'pages' => array('post'),

    'fields' => array(
    	/**/
        array(
            'name' => 'Subtitle',
            'id' => $prefix . 'subtitle',
            'desc' => 'The Subtitle that will be shown below post/page title.',
            'type' => 'text'
        ),
        array(
            'name' => 'Editor Rating',
           'id' => $prefix . 'rating',
            'desc' => 'Select the Rating for this post. From 2 to 5 stars.',
            'type' => 'select',
            'options' => array('0' => '', '2' => '2', '2.5' => '2.5', '3' => '3', '3.5' => '3.5', '4' => '4', '4.5' => '4.5', '5' => '5')
        ),
        
        array(
            'name' => 'Full Width',
            'id' => $prefix . 'fullwidth',
            'desc' => 'Check this box to make this post Full Width. The sidebar will be hidden.',
            'type' => 'checkbox'
        )

	)
);

// meta box
global $data;
$meta_boxes[] = array(
    'id' => 'affiliate_options',
    'title' => 'Affiliate Options',
    'pages' => array('post'),
    'fields' => array(
        array(
            'name' => 'Target URL',
           'id' => $prefix . 'targeturl',
            'desc' => 'Enter the target URL here, e.g. http://www.website.com/. It can be any affiliate link or any target URL.',
            'type' => 'text'
        )
    )
);

/* meta box */
$meta_boxes[] = array(
	'id' => 'page_options',
	'title' => 'Page Options',
	'pages' => array('page'),

    'fields' => array(
        array(
            'name' => 'Subtitle',
            'id' => $prefix . 'subtitle',
            'desc' => 'The Subtitle that will be shown below post/page title.',
            'type' => 'text'
        ),
        array(
            'name' => 'Full Width',
            'id' => $prefix . 'fullwidth',
            'desc' => 'Check this box to make this post Full Width. The sidebar will be hidden.',
            'type' => 'checkbox'
        ),
        array(
            'name' => 'Category',
            'desc' => 'Type the category ID, separated by comma (,). Leave it empty to display posts form all categories. It will only affect if you select the <strong>Blog Template</strong> and <strong>Portfolio Template</strong> (see the right of your editor on the Page Attributes section).<br>Below is a list of categories name and ID for your reference:',
            'id' => $prefix . 'cat_page',
            'type' => 'text'
        ),        
        array(
            'name' => '',
            'desc' => '',
            'id' => $prefix . 'list_allcat',
            'type' => 'checkbox_list',
            'options' => $of_categories2
        ),        
        array(
            'name' => 'Columns',
           'id' => $prefix . 'columns',
            'desc' => 'Select the number of column. It will only affect if you select the <strong>Portfolio Template</strong>',
            'type' => 'select',
            'options' => array('2' => '2 Columns', '3' => '3 Columns', '4' => '4 Columns')
        ),
        array(
            'name' => 'Blank At All Template CSS',
           'id' => $prefix . 'blankatall_css',
            'desc' => 'Enter CSS Code of Blank At All Template you are using.',
            'type' => 'text'
        ),
        array(
            'name' => 'Blank At All Template Script',
           'id' => $prefix . 'blankatall_script',
            'desc' => 'Enter Script (usually Javascript) Code of Blank At All Template you are using.',
            'type' => 'text'
        )

	)
);


foreach ($meta_boxes as $meta_box) {
	$my_box = new RW_Meta_Box_Taxonomy($meta_box);
}

/********************* END DEFINITION OF META BOXES ***********************/

/********************* BEGIN VALIDATION ***********************/

/**
 * Validation class
 * Define ALL validation methods inside this class
 * Use the names of these methods in the definition of meta boxes (key 'validate_func' of each field)
 */
class RW_Meta_Box_Validate {
	function check_name($text) {
		if ($text == 'Anh Tran') {
			return 'He is Rilwis';
		}
		return $text;
	}
}

/********************* END VALIDATION ***********************/
?>
